@@ -67,6 +67,7 @@ use G::Seq::ORF;
 use G::Seq::Align;
 use G::Seq::Usage;
 use G::Seq::COMGA;
+use G::Seq::GenomeMap;
 use G::Seq::ImaGene;
 use G::Tools::Graph;
 use G::Tools::H2v;
@@ -87,13 +88,10 @@ use G::Tools::GlimmerM;
 use G::Tools::Literature;
 use G::Tools::KEGG_API;
 use G::Tools::KEGG_API3;
-use G::Tools::RCluster;
 use G::Tools::PEC;
 use G::Tools::Statistics;
-use G::SystemsBiology::Serizawa;
-use G::SystemsBiology::Pathway;
+use G::Tools::GMap;
 use G::SystemsBiology::PathwayAlignment;
-use G::SystemsBiology::EcellReader;
 use G::SystemsBiology::KEGG;
 use G::SystemsBiology::BioLayout;
 use G::SystemsBiology::Interaction;
@@ -133,6 +131,7 @@ push(@EXPORT, @G::Seq::Align::EXPORT);
 push(@EXPORT, @G::Seq::Usage::EXPORT);
 push(@EXPORT, @G::Seq::COMGA::EXPORT);
 push(@EXPORT, @G::Seq::ImaGene::EXPORT);
+push(@EXPORT, @G::Seq::GenomeMap::EXPORT);
 push(@EXPORT, @G::Tools::Graph::EXPORT);
 push(@EXPORT, @G::Tools::H2v::EXPORT);
 push(@EXPORT, @G::Tools::Mapping::EXPORT);
@@ -152,13 +151,10 @@ push(@EXPORT, @G::Tools::GlimmerM::EXPORT);
 push(@EXPORT, @G::Tools::Literature::EXPORT);
 push(@EXPORT, @G::Tools::KEGG_API::EXPORT);
 push(@EXPORT, @G::Tools::KEGG_API3::EXPORT);
-push(@EXPORT, @G::Tools::RCluster::EXPORT);
 push(@EXPORT, @G::Tools::PEC::EXPORT);
 push(@EXPORT, @G::Tools::Statistics::EXPORT);
-push(@EXPORT, @G::SystemsBiology::Serizawa::EXPORT);
-push(@EXPORT, @G::SystemsBiology::Pathway::EXPORT);
+push(@EXPORT, @G::Tools::GMap::EXPORT);
 push(@EXPORT, @G::SystemsBiology::PathwayAlignment::EXPORT);
-push(@EXPORT, @G::SystemsBiology::EcellReader::EXPORT);
 push(@EXPORT, @G::SystemsBiology::KEGG::EXPORT);
 push(@EXPORT, @G::SystemsBiology::BioLayout::EXPORT);
 push(@EXPORT, @G::SystemsBiology::Interaction::EXPORT);
