@@ -99,7 +99,7 @@ sub sample_data_for_normality{
   Options:
    -method       name of the test
                  "ad" for Anderson-Darling 
-                 "ks" for Kolmogorov-Smirnov Lillifors (default)
+                 "ks" for Kolmogorov-Smirnov Lilliefors (default)
                  "sw" for Shapiro-Wilk
    -sampledata   use sample data (default: 0)
 
@@ -130,7 +130,7 @@ sub normtest{
 	$rcmd->array('rnormality', @args);
 	
 	if(scalar(@args) > 5000 && $method eq 'sw'){
-	    carp("Shapiro-Wilk test cannot handle samples >5000.\nUsing Kolmogorov-Smirnov Lillifors instead.\n");
+	    carp("Shapiro-Wilk test cannot handle samples >5000.\nUsing Kolmogorov-Smirnov Lilliefors instead.\n");
 	    $method = "ks";
 	}
     }
